@@ -68,15 +68,6 @@
  **/
 #define BOOK_BACKEND_PROPERTY_SUPPORTED_FIELDS		"supported-fields"
 
-/**
- * E_BOOK_CLIENT_ERROR:
- *
- * FIXME: Document me.
- *
- * Since: 3.2
- **/
-#define E_BOOK_CLIENT_ERROR e_book_client_error_quark ()
-
 G_BEGIN_DECLS
 
 typedef struct _EBookClient        EBookClient;
@@ -247,7 +238,7 @@ void		e_book_client_get_contacts	(EBookClient *client,
 gboolean	e_book_client_get_contacts_finish
 						(EBookClient *client,
 						 GAsyncResult *result,
-						 GSList **contacts,
+						 GSList **out_contacts,
 						 GError **error);
 gboolean	e_book_client_get_contacts_sync	(EBookClient *client,
 						 const gchar *sexp,
