@@ -480,16 +480,18 @@ emit_notifications_in_idle (gpointer user_data)
     }
 
 	if (has_changes) {
-		g_dbus_connection_emit_signal (connection,
-					NULL,
-					path,
-					"org.freedesktop.DBus.Properties",
-					"PropertiesChanged",
-					g_variant_new ("(sa{sv}as)",
-							GDBUS_CAL_VIEW_INTERFACE_NAME,
-							builder,
-							invalidated_builder),
-					NULL);
+		g_dbus_connection_emit_signal (
+			connection,
+			NULL,
+			path,
+			"org.freedesktop.DBus.Properties",
+			"PropertiesChanged",
+			g_variant_new (
+				"(sa{sv}as)",
+				GDBUS_CAL_VIEW_INTERFACE_NAME,
+				builder,
+				invalidated_builder),
+				NULL);
 	} else {
 		g_variant_builder_unref (builder);
 		g_variant_builder_unref (invalidated_builder);
@@ -558,7 +560,8 @@ e_gdbus_cal_view_register_object (EGdbusCalView *object,
 	g_object_set_data_full (G_OBJECT (object), "gdbus-codegen-path", (gpointer) g_strdup (object_path), g_free);
 	g_object_set_data (G_OBJECT (object), "gdbus-codegen-connection", (gpointer) connection);
 	g_object_set_data_full (G_OBJECT (object), "gdbus-codegen-pvc", (gpointer) pvc, (GDestroyNotify) g_hash_table_unref);
-	return g_dbus_connection_register_object (connection,
+	return g_dbus_connection_register_object (
+		connection,
 		object_path,
 		(GDBusInterfaceInfo *) &_e_gdbus_cal_view_interface_info,
 		&e_gdbus_cal_view_interface_vtable,
@@ -647,17 +650,18 @@ e_gdbus_cal_view_proxy_new (GDBusConnection *connection,
                             GAsyncReadyCallback callback,
                             gpointer user_data)
 {
-	g_async_initable_new_async (E_TYPE_GDBUS_CAL_VIEW_PROXY,
-				G_PRIORITY_DEFAULT,
-				cancellable,
-				callback,
-				user_data,
-				"g-flags", flags,
-				"g-name", name,
-				"g-connection", connection,
-				"g-object-path", object_path,
-				"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
-				NULL);
+	g_async_initable_new_async (
+		E_TYPE_GDBUS_CAL_VIEW_PROXY,
+		G_PRIORITY_DEFAULT,
+		cancellable,
+		callback,
+		user_data,
+		"g-flags", flags,
+		"g-name", name,
+		"g-connection", connection,
+		"g-object-path", object_path,
+		"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
+		NULL);
 }
 
 /**
@@ -709,15 +713,16 @@ e_gdbus_cal_view_proxy_new_sync (GDBusConnection *connection,
                                  GError **error)
 {
 	GInitable *initable;
-	initable = g_initable_new (E_TYPE_GDBUS_CAL_VIEW_PROXY,
-				cancellable,
-				error,
-				"g-flags", flags,
-				"g-name", name,
-				"g-connection", connection,
-				"g-object-path", object_path,
-				"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
-				NULL);
+	initable = g_initable_new (
+		E_TYPE_GDBUS_CAL_VIEW_PROXY,
+		cancellable,
+		error,
+		"g-flags", flags,
+		"g-name", name,
+		"g-connection", connection,
+		"g-object-path", object_path,
+		"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
+		NULL);
 	if (initable != NULL)
 		return E_GDBUS_CAL_VIEW (initable);
 	else
@@ -747,17 +752,18 @@ e_gdbus_cal_view_proxy_new_for_bus (GBusType bus_type,
                                     GAsyncReadyCallback callback,
                                     gpointer user_data)
 {
-	g_async_initable_new_async (E_TYPE_GDBUS_CAL_VIEW_PROXY,
-				G_PRIORITY_DEFAULT,
-				cancellable,
-				callback,
-				user_data,
-				"g-flags", flags,
-				"g-name", name,
-				"g-bus-type", bus_type,
-				"g-object-path", object_path,
-				"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
-				NULL);
+	g_async_initable_new_async (
+		E_TYPE_GDBUS_CAL_VIEW_PROXY,
+		G_PRIORITY_DEFAULT,
+		cancellable,
+		callback,
+		user_data,
+		"g-flags", flags,
+		"g-name", name,
+		"g-bus-type", bus_type,
+		"g-object-path", object_path,
+		"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
+		NULL);
 }
 
 /**
@@ -809,15 +815,16 @@ e_gdbus_cal_view_proxy_new_for_bus_sync (GBusType bus_type,
                                          GError **error)
 {
 	GInitable *initable;
-	initable = g_initable_new (E_TYPE_GDBUS_CAL_VIEW_PROXY,
-				cancellable,
-				error,
-				"g-flags", flags,
-				"g-name", name,
-				"g-bus-type", bus_type,
-				"g-object-path", object_path,
-				"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
-				NULL);
+	initable = g_initable_new (
+		E_TYPE_GDBUS_CAL_VIEW_PROXY,
+		cancellable,
+		error,
+		"g-flags", flags,
+		"g-name", name,
+		"g-bus-type", bus_type,
+		"g-object-path", object_path,
+		"g-interface-name", GDBUS_CAL_VIEW_INTERFACE_NAME,
+		NULL);
 	if (initable != NULL)
 		return E_GDBUS_CAL_VIEW (initable);
 	else
