@@ -7,6 +7,7 @@
 #include "e-test-server-utils.h"
 
 static ETestServerClosure book_closure = { E_TEST_SERVER_ADDRESS_BOOK, NULL, 0 };
+static ETestServerClosure direct_book_closure = { E_TEST_SERVER_DIRECT_ADDRESS_BOOK, NULL, 0 };
 
 #define NOTIFICATION_WAIT 2000
 
@@ -188,6 +189,12 @@ main (gint argc,
 	g_test_add (
 		"/EBookClient/SuppressNotifications/Async", ETestServerFixture, &book_closure,
 		e_test_server_utils_setup, test_suppress_notifications_async, e_test_server_utils_teardown);
+	g_test_add (
+		"/EBookClient/DirectAccess/SuppressNotifications/Sync", ETestServerFixture, &direct_book_closure,
+		e_test_server_utils_setup, test_suppress_notifications_sync, e_test_server_utils_teardown);
+	g_test_add (
+		"/EBookClient/DirectAccess/SuppressNotifications/Async", ETestServerFixture, &direct_book_closure,
+		e_test_server_utils_setup, test_suppress_notifications_async, e_test_server_utils_teardown);
 
 	return e_test_server_utils_run ();
 }
