@@ -40,10 +40,9 @@ get_required_fields_cb (EBookTestClosure *closure)
 	g_main_loop_quit ((GMainLoop *) (closure->user_data));
 }
 
-
 static void
 test_get_required_fields_sync (ETestServerFixture *fixture,
-			       gconstpointer       user_data)
+                               gconstpointer user_data)
 {
 	EBook *book;
 	GList *fields;
@@ -59,7 +58,7 @@ test_get_required_fields_sync (ETestServerFixture *fixture,
 
 static void
 test_get_required_fields_async (ETestServerFixture *fixture,
-				gconstpointer       user_data)
+                                gconstpointer user_data)
 {
 	EBook *book;
 
@@ -78,10 +77,12 @@ main (gint argc,
 #endif
 	g_test_init (&argc, &argv, NULL);
 
-	g_test_add ("/EBook/GetRequiredFields/Sync", ETestServerFixture, &book_closure,
-		    e_test_server_utils_setup, test_get_required_fields_sync, e_test_server_utils_teardown);
-	g_test_add ("/EBook/GetRequiredFields/Async", ETestServerFixture, &book_closure,
-		    e_test_server_utils_setup, test_get_required_fields_async, e_test_server_utils_teardown);
+	g_test_add (
+		"/EBook/GetRequiredFields/Sync", ETestServerFixture, &book_closure,
+		e_test_server_utils_setup, test_get_required_fields_sync, e_test_server_utils_teardown);
+	g_test_add (
+		"/EBook/GetRequiredFields/Async", ETestServerFixture, &book_closure,
+		e_test_server_utils_setup, test_get_required_fields_async, e_test_server_utils_teardown);
 
 	return e_test_server_utils_run ();
 }
