@@ -116,6 +116,24 @@ e_test_server_utils_bootstrap_timeout (FixturePair *pair)
 	return FALSE;
 }
 
+static void
+registry_weak_notify (gpointer data,
+		      GObject *where_the_object_was)
+{
+	ETestServerFixture *fixture = (ETestServerFixture *)data;
+
+	fixture->registry_finalized = TRUE;
+}
+
+static void
+client_weak_notify (gpointer data,
+		    GObject *where_the_object_was)
+{
+	ETestServerFixture *fixture = (ETestServerFixture *)data;
+
+	fixture->client_finalized = TRUE;
+}
+
 static void
 e_test_server_utils_source_added (ESourceRegistry *registry,
                                   ESource *source,
@@ -140,6 +158,9 @@ e_test_server_utils_source_added (ESourceRegistry *registry,
 		if (!pair->fixture->service.book_client)
 			g_error ("Unable to create the test book: %s", error->message);
 
+		g_object_weak_ref (G_OBJECT (pair->fixture->service.book_client),
+				   client_weak_notify, pair->fixture);
+
 		break;
 
 	case E_TEST_SERVER_DEPRECATED_ADDRESS_BOOK:
@@ -151,6 +172,9 @@ e_test_server_utils_source_added (ESourceRegistry *registry,
 		if (!e_book_open (pair->fixture->service.book, FALSE, &error))
 			g_error ("Unable to open book: %s", error->message);
 
+		g_object_weak_ref (G_OBJECT (pair->fixture->service.book),
+				   client_weak_notify, pair->fixture);
+
 		break;
 
 	case E_TEST_SERVER_CALENDAR:
@@ -162,6 +186,9 @@ e_test_server_utils_source_added (ESourceRegistry *registry,
 		if (!pair->fixture->service.calendar_client)
 			g_error ("Unable to create the test calendar: %s", error->message);
 
+		g_object_weak_ref (G_OBJECT (pair->fixture->service.calendar_client),
+				   client_weak_notify, pair->fixture);
+
 		break;
 
 	case E_TEST_SERVER_DEPRECATED_CALENDAR:
@@ -173,6 +200,9 @@ e_test_server_utils_source_added (ESourceRegistry *registry,
 		if (!e_cal_open (pair->fixture->service.calendar, FALSE, &error))
 			g_error ("Unable to open calendar: %s", error->message);
 
+		g_object_weak_ref (G_OBJECT (pair->fixture->service.calendar),
+				   client_weak_notify, pair->fixture);
+
 		break;
 
 	case E_TEST_SERVER_NONE:
@@ -194,6 +224,9 @@ e_test_server_utils_bootstrap_idle (FixturePair *pair)
 	if (!pair->fixture->registry)
 		g_error ("Unable to create the test registry: %s", error->message);
 
+	g_object_weak_ref (G_OBJECT (pair->fixture->registry),
+			   registry_weak_notify, pair->fixture);
+
 	g_signal_connect (
 		pair->fixture->registry, "source-added",
 		G_CALLBACK (e_test_server_utils_source_added), pair);
@@ -321,7 +354,7 @@ e_test_server_utils_teardown (ETestServerFixture *fixture,
 	switch (closure->type) {
 	case E_TEST_SERVER_ADDRESS_BOOK:
 	case E_TEST_SERVER_DIRECT_ADDRESS_BOOK:
-		if (!e_client_remove_sync (E_CLIENT (fixture->service.book_client), NULL, &error)) {
+		if (!closure->keep_work_directory && !e_client_remove_sync (E_CLIENT (fixture->service.book_client), NULL, &error)) {
 			g_message ("Failed to remove test book: %s (ignoring)", error->message);
 			g_clear_error (&error);
 		}
@@ -330,7 +363,7 @@ e_test_server_utils_teardown (ETestServerFixture *fixture,
 		break;
 
 	case E_TEST_SERVER_DEPRECATED_ADDRESS_BOOK:
-		if (!e_book_remove (fixture->service.book, &error)) {
+		if (!closure->keep_work_directory && !e_book_remove (fixture->service.book, &error)) {
 			g_message ("Failed to remove test book: %s (ignoring)", error->message);
 			g_clear_error (&error);
 		}
@@ -339,7 +372,7 @@ e_test_server_utils_teardown (ETestServerFixture *fixture,
 		break;
 
 	case E_TEST_SERVER_CALENDAR:
-		if (!e_client_remove_sync (E_CLIENT (fixture->service.calendar_client), NULL, &error)) {
+		if (!closure->keep_work_directory && !e_client_remove_sync (E_CLIENT (fixture->service.calendar_client), NULL, &error)) {
 			g_message ("Failed to remove test calendar: %s (ignoring)", error->message);
 			g_clear_error (&error);
 		}
@@ -348,7 +381,7 @@ e_test_server_utils_teardown (ETestServerFixture *fixture,
 		break;
 
 	case E_TEST_SERVER_DEPRECATED_CALENDAR:
-		if (!e_cal_remove (fixture->service.calendar, &error)) {
+		if (!closure->keep_work_directory && !e_cal_remove (fixture->service.calendar, &error)) {
 			g_message ("Failed to remove test calendar: %s (ignoring)", error->message);
 			g_clear_error (&error);
 		}
@@ -359,11 +392,18 @@ e_test_server_utils_teardown (ETestServerFixture *fixture,
 		break;
 	}
 
+	if (closure->type != E_TEST_SERVER_NONE &&
+	    fixture->client_finalized == FALSE)
+		g_error ("Failed to destroy client while tearing down test case; reference count imbalance");
+
 	g_free (fixture->source_name);
 	g_object_run_dispose (G_OBJECT (fixture->registry));
 	g_object_unref (fixture->registry);
 	fixture->registry = NULL;
 
+	if (fixture->registry_finalized == FALSE)
+		g_error ("Failed to destroy registry while tearing down test case; reference count imbalance");
+
 	g_main_loop_unref (fixture->loop);
 	fixture->loop = NULL;
 
